@@ -11,7 +11,7 @@
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
-# obtain one at http://mozilla.org/MPL/2.0/.
+# obtain one at https://mozilla.org/MPL/2.0/.
 #
 # END HEADER
 
@@ -26,12 +26,6 @@ from hypothesis.internal.compat import (
     struct_unpack,
 )
 
-try:
-    import numpy
-except ImportError:
-    numpy = None
-
-
 # Format codes for (int, float) sized types, used for byte-wise casts.
 # See https://docs.python.org/3/library/struct.html#format-characters
 STRUCT_FORMATS = {
@@ -44,25 +38,30 @@ STRUCT_FORMATS = {
 # There are two versions of this: the one that uses Numpy to support Python
 # 3.5 and earlier, and the elegant one for new versions.  We use the new
 # one if Numpy is unavailable too, because it's slightly faster in all cases.
-if numpy and not CAN_PACK_HALF_FLOAT:  # pragma: no cover
-
-    def reinterpret_bits(x, from_, to):
-        if from_ == b"!e":
-            arr = numpy.array([x], dtype=">f2")
-            if numpy.isfinite(x) and not numpy.isfinite(arr[0]):
-                quiet_raise(OverflowError("%r too large for float16" % (x,)))
-            buf = arr.tobytes()
-        else:
-            buf = struct_pack(from_, x)
-        if to == b"!e":
-            return float(numpy.frombuffer(buf, dtype=">f2")[0])
-        return struct_unpack(to, buf)[0]
+def reinterpret_bits(x, from_, to):
+    return struct_unpack(to, struct_pack(from_, x))[0]
 
 
-else:
+if not CAN_PACK_HALF_FLOAT:  # pragma: no cover
+    try:
+        import numpy
+    except (ImportError, TypeError):
+        # We catch TypeError because that can be raised if Numpy is installed on
+        # PyPy for Python 2.7; and we only need a workaround until 2020-01-01.
+        pass
+    else:
 
-    def reinterpret_bits(x, from_, to):
-        return struct_unpack(to, struct_pack(from_, x))[0]
+        def reinterpret_bits(x, from_, to):  # pylint: disable=function-redefined
+            if from_ == b"!e":
+                arr = numpy.array([x], dtype=">f2")
+                if numpy.isfinite(x) and not numpy.isfinite(arr[0]):
+                    quiet_raise(OverflowError("%r too large for float16" % (x,)))
+                buf = arr.tobytes()
+            else:
+                buf = struct_pack(from_, x)
+            if to == b"!e":
+                return float(numpy.frombuffer(buf, dtype=">f2")[0])
+            return struct_unpack(to, buf)[0]
 
 
 def float_of(x, width):
@@ -118,8 +117,8 @@ def next_up(value, width=64):
     assert isinstance(value, float)
     if math.isnan(value) or (math.isinf(value) and value > 0):
         return value
-    if value == 0.0:
-        value = 0.0
+    if value == 0.0 and is_negative(value):
+        return 0.0
     fmt_int, fmt_flt = STRUCT_FORMATS[width]
     # Note: n is signed; float_to_int returns unsigned
     fmt_int = fmt_int.lower()
